<div align="center">
    <img src="https://user-images.githubusercontent.com/87452561/126879489-76401030-d407-4b34-b041-cc015f069daa.png" alt="GeoSnipe Logo" width="300" height="300">

[![made-with-python](https://img.shields.io/badge/Made%20with-Python-1f425f.svg)](https://www.python.org/)
[![Contributors](https://img.shields.io/github/contributors/Geographs/GeoSnipe)](https://github.com/Geographs/GeoSnipe/graphs/contributors)
[![Forks](https://img.shields.io/github/forks/Geographs/GeoSnipe)](https://github.com/Geographs/GeoSnipe/network/members)
[![Stargazers](https://img.shields.io/github/stars/Geographs/GeoSnipe)](https://github.com/Geographs/GeoSnipe/stargazers)
[![Issues](https://img.shields.io/github/issues/Geographs/GeoSnipe)](https://github.com/Geographs/GeoSnipe/issues)
[![MIT License](https://img.shields.io/github/license/Geographs/GeoSnipe)](https://github.com/Geographs/GeoSnipe/blob/main/LICENSE)
[![Documentation Status](https://img.shields.io/badge/docs-passing-green.svg)](https://geographs.pro/GeoSnipe/)

[![Maintenance](https://img.shields.io/badge/Maintained-yes-lightgreen.svg)](https://github.com/Geographs/GeoSnipe)
[![Maintaner](https://img.shields.io/badge/Maintainer-Geographs-lightblue)](https://github.com/Geographs)
</div>

# GeoSnipe
A pythonic Minecraft username sniper based on asyncio.

# Documentation
https://geographs.pro/GeoSnipe/
